@@ -25,11 +25,10 @@ class SSLifyMiddlwareTest(TestCase):
         self.assertTrue(request.build_absolute_uri().startswith('http://'))
 
         middleware = SSLifyMiddleware()
-        request = middleware.process_request(request)
+        result = middleware.process_request(request)
 
-        self.assertIsInstance(request, HttpResponsePermanentRedirect)
-        self.assertTrue(request['Location'].startswith('https://'))
-        self.assertEqual(443, urlsplit(request['Location']).port)
+        self.assert_https_redirect(result)
+        self.assertEqual(443, urlsplit(result['Location']).port)
 
     def test_custom_ssl_port(self):
         custom_port = 8443
@@ -45,5 +44,23 @@ class SSLifyMiddlwareTest(TestCase):
             request = self.client.get('/woot/')
             self.assertEqual(404, request.status_code)
 
+    def test_disable_for_url(self):
+        def sslify_disable(request):
+            return request.get_full_path().startswith('/disabled')
+
+        with self.settings(SSLIFY_DISABLE_FOR_REQUEST=[sslify_disable]):
+            middleware = SSLifyMiddleware()
+            request = self.factory.get('/disabled/')
+            request = middleware.process_request(request)
+            self.assertIsNone(request)
+
+            request = self.factory.get('/enabled/')
+            result = middleware.process_request(request)
+            self.assert_https_redirect(result)
+
+    def assert_https_redirect(self, result):
+        self.assertIsInstance(result, HttpResponsePermanentRedirect)
+        self.assertTrue(result['Location'].startswith('https://'))
+
     def tearDown(self):
         del self.factory
